@@ -52,6 +52,7 @@ const _ChatroomManager = new Lang.Class({
         this._accountsMonitor = AccountsMonitor.getDefault();
         this._accountsMonitor.connect('account-manager-prepared',
                                       Lang.bind(this, this._onPrepared));
+        this._amIsPrepared = false;
     },
 
     _onPrepared: function(mon, am) {
@@ -85,6 +86,17 @@ const _ChatroomManager = new Lang.Class({
             }));
         this._client.register();
 
+        this._amIsPrepared = true;
+        this.lateInit();
+    },
+
+    lateInit: function() {
+        let am = this._accountsMonitor.accountManager;
+        let ready = this._amIsPrepared &&
+            this._app.get_active_window() != null;
+        if (!ready)
+            return;
+
         am.connect('account-enabled',
                    Lang.bind(this, this._onAccountEnabled));
         am.connect('account-disabled',
@@ -231,14 +243,18 @@ const _ChatroomManager = new Lang.Class({
 
         this._processRequest(context, connection, channels, Lang.bind(this,
             function(channel) {
+                if (!this._app.get_active_window())
+                    this._app.activate();
+
                 let room = this._ensureRoomForChannel(channel);
                 //channel.join_async('', null);
 
                 if (present || this.roomCount == 1)
                     this.setActiveRoom(room);
+
+                if (present)
+                    this._app.get_active_window().present_with_time(time);
             }));
-        if (present)
-            this._app.get_active_window().present_with_time(time);
     },
 
     _addRoom: function(room) {
