@@ -109,6 +109,9 @@ const EntryArea = new Lang.Class({
         if (!this._entry.get_mapped())
             return Gdk.EVENT_PROPAGATE;
 
+        if (!this.widget.sensitive)
+            return Gdk.EVENT_PROPAGATE;
+
         if (this._entry.has_focus)
             return Gdk.EVENT_PROPAGATE;
 
@@ -120,7 +123,7 @@ const EntryArea = new Lang.Class({
             return Gdk.EVENT_PROPAGATE;
 
         let [, state] = event.get_state();
-        if (state != 0)
+        if (state != 0 && state != Gdk.ModifierType.SHIFT_MASK)
             return Gdk.EVENT_PROPAGATE;
 
         let activationKeys = [
